.. Copyright (c) Jupyter Development Team.
.. Distributed under the terms of the Modified BSD License.

---------------------
JupyterLab Server API
---------------------

JupyterLab Server API Reference:

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    app-config
    app
    config
    handlers
    process
    rest
    spec
